import React, { useEffect, useState } from 'react'
import { Button, Descriptions, List, Modal } from 'antd'
import router from 'umi/router'
import { fetch, apis } from '@/utils/request'
import Section from './Section'
import Edit from './Edit'

const VerifyStatusDict = {
  '0': '未审核',
  '1': '通过',
  '2': '不通过',
}

const verifyinfoAdd = fetch(apis.buildingOwnerInfo.verifyinfoAdd)

export default props => {
  const [editorShow, setEditorShow] = useState(false)
  const { userData = {} } = props
  
  const roomName = userData.phaseName + userData.buildingName + userData.unitName + userData.levelName + userData.roomNoName

  const handleEdit = vals => {
    verifyinfoAdd({ urlData: { id: userData.id }, params: vals }).then(res => {
      Modal.success({
        content: '提交修改成功',
        onOk: () => {
          setEditorShow(false)
        }
      })
    })
  }

  return (
    <div>
      <Section title="基本信息">
        <Descriptions column={3}>
          <Descriptions.Item label="姓名">{userData.ownerName}</Descriptions.Item>
          <Descriptions.Item label="性别">{!userData.idCard ? '' : (userData.idCard.substring(16, 17) - 0) % 2 === 1 ? '男' : '女'}</Descriptions.Item>
          <Descriptions.Item label="手机号">{userData.phone}</Descriptions.Item>
          <Descriptions.Item label="微信昵称">{userData.nickname}</Descriptions.Item>
          <Descriptions.Item label="总积分">{userData.totalPoints || 0}</Descriptions.Item>
          <Descriptions.Item label="身份证">{userData.idCard}</Descriptions.Item>
          <Descriptions.Item label="头像">
            <img src={userData.avatarurl} alt="" style={{ width: '64px', height: '64px' }}/>
          </Descriptions.Item>
        </Descriptions>
      </Section>
      <Section title="在当前房屋" subTitle={roomName} action={<Button type="link" onClick={() => setEditorShow(true)}>修改</Button>}>
        <Descriptions column={3}>
          <Descriptions.Item label="身份">业主</Descriptions.Item>
          <Descriptions.Item label="审核状态">{VerifyStatusDict[userData.status]}</Descriptions.Item>
          <Descriptions.Item label="资料手机">{userData.phone}</Descriptions.Item>
          {/* <Descriptions.Item label="人脸">
            <img src={userData.faceImg} alt="" style={{ width: '128px', height: '128px' }}/>
          </Descriptions.Item> */}
        </Descriptions>
      </Section>
      <Section title="关联本小区其他房屋" subTitle="使用用户手机号在小区用户列表中搜索查看">
        <List dataSource={userData.roomInfoList || []} renderItem={x => (<List.Item>{x}</List.Item>)} size="small" />
      </Section>
      <Edit
        visible={editorShow}
        userData={userData}
        onSubmit={handleEdit}
        onCancel={() => setEditorShow(false)}
      />
    </div>
  )
}
